==> apache-ftpserver-1.2.0-src.zip: apache-ftpserver-1.2.0/src/core/src/main/java/org/apache/ftpserver/FtpServerConfigurationException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.ftpserver;

/**
 * Exception used during startup to indicate that the configuration is not
 * correct.
 *
 * @author <a href="http://mina.apache.org">Apache MINA Project</a>
 */
public class FtpServerConfigurationException extends RuntimeException {

    private static final long serialVersionUID = -1328432839915898987L;

    /**
     * {@link RuntimeException#RuntimeException()}
     */
    public FtpServerConfigurationException() {
        super();
    }

    /**
     * {@link RuntimeException#RuntimeException(String, Throwable)}
     */
    public FtpServerConfigurationException(final String message,
            final Throwable cause) {
        super(message, cause);
    }

    /**
     * {@link RuntimeException#RuntimeException(String)}
     */
    public FtpServerConfigurationException(final String message) {
        super(message);
    }

    /**
     * {@link RuntimeException#RuntimeException(Throwable)}
     */
    public FtpServerConfigurationException(final Throwable cause) {
        super(cause);
    }

}

==> apache-ftpserver-1.2.1-src.zip: apache-ftpserver-1.2.1/src/core/src/main/java/org/apache/ftpserver/FtpServerConfigurationException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.ftpserver;

/**
 * Exception used during startup to indicate that the configuration is not
 * correct.
 *
 * @author <a href="http://mina.apache.org">Apache MINA Project</a>
 */
public class FtpServerConfigurationException extends RuntimeException {

    private static final long serialVersionUID = -1328432839915898987L;

    /**
     * {@link RuntimeException#RuntimeException()}
     */
    public FtpServerConfigurationException() {
        super();
    }

    /**
     * {@link RuntimeException#RuntimeException(String, Throwable)}
     *
     * @param message The message to propagate
     * @param cause The root cause
     */
    public FtpServerConfigurationException(final String message,
            final Throwable cause) {
        super(message, cause);
    }

    /**
     * {@link RuntimeException#RuntimeException(String)}
     *
     * @param message The message to propagate
     */
    public FtpServerConfigurationException(final String message) {
        super(message);
    }

    /**
     * {@link RuntimeException#RuntimeException(Throwable)}
     *
     * @param cause The root cause
     */
    public FtpServerConfigurationException(final Throwable cause) {
        super(cause);
    }

}
